@@ -7,7 +7,8 @@ from .bed_expansion_factor import fbexp
 from .biomass_composition import biocomp
 from .biomass_composition import plot_biocomp
 
-from .bubble_velocity import ubr
+from .bubble_rise_velocity import ubr_kunii
+from .bubble_rise_velocity import ubr_holland
 
 from .chemical_equation import ChemicalEquation
 
@@ -20,6 +21,12 @@ from .conversions import molefrac_to_massfrac
 
 from .devol_time import devol_time
 
+from .dimensionless_numbers import biot
+from .dimensionless_numbers import prandtl
+from .dimensionless_numbers import pyroI
+from .dimensionless_numbers import pyroII
+from .dimensionless_numbers import reynolds
+
 from .gas_density import rhog
 from .gas_pressure import patm
 from .gas_thermal_conductivity import k_gas_inorganic
@@ -37,6 +44,8 @@ from .minimum_fluidization_velocity import umf_reynolds
 from .molecular_weight import mw
 from .molecular_weight import mw_mix
 
+from .proximate_bases import proximate_bases
+
 from .terminal_velocity import ut
 from .terminal_velocity import ut_haider
 from .terminal_velocity import ut_ganser
@@ -45,5 +54,7 @@ from .transport_disengaging_height import tdh_chan
 from .transport_disengaging_height import tdh_horio
 from .transport_velocity import utr
 
+from .ultimate_bases import ultimate_bases
+
 from .wood_heat_capacity import cp_wood
 from .wood_thermal_conductivity import k_wood
